@@ -12,7 +12,6 @@ import { State, Action } from '../state';
 import { DiscoveryDonutChart } from './donut-chart';
 import {
   minSelectedNode,
-  diskTypeDropdownItems,
   diskModeDropdownItems,
   allNodesSelectorTxt,
 } from '../../../../../constants';
@@ -46,7 +45,6 @@ export const CreateLocalVolumeSet: React.FC<CreateLocalVolumeSetProps> = ({
           <LocalVolumeSetInner
             state={state}
             dispatch={dispatch}
-            diskTypeOptions={diskTypeDropdownItems}
             diskModeOptions={diskModeDropdownItems}
             allNodesHelpTxt={allNodesSelectorTxt}
           />
@@ -83,7 +81,6 @@ const ConfirmationModal = ({ state, dispatch, ns }) => {
   };
 
   const cancel = () => {
-    dispatch({ type: 'setCreateLVS', value: false });
     dispatch({ type: 'setShowConfirmModal', value: false });
   };
 
