@@ -6,6 +6,7 @@ import {
   DashboardsOverviewHealthResourceSubsystem,
   DashboardsOverviewUtilizationItem,
   DashboardsTab,
+  HorizontalNavTab,
   KebabActions,
   ModelDefinition,
   ModelFeatureFlag,
@@ -15,25 +16,30 @@ import {
   ResourceDetailsPage,
   DashboardsOverviewResourceActivity,
   CustomFeatureFlag,
+  StorageClassProvisioner,
 } from '@console/plugin-sdk';
+import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager/src/models';
+import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
+import { referenceForModel } from '@console/internal/module/k8s';
+import { NodeModel } from '@console/internal/models';
+import { LSO_DEVICE_DISCOVERY } from '@console/local-storage-operator-plugin/src/plugin';
+import { getCephHealthState } from './components/dashboard-page/storage-dashboard/status-card/utils';
+import { isClusterExpandActivity } from './components/dashboard-page/storage-dashboard/activity-card/cluster-expand-activity';
+import { StorageClassFormProvisoners } from './utils/ocs-storage-class-params';
+import { WatchCephResource } from './types';
 import {
   detectOCS,
   detectOCSSupportedFeatures,
+  detectRGW,
   CEPH_FLAG,
   OCS_INDEPENDENT_FLAG,
-  OCS_SUPPORT_FLAGS,
   OCS_CONVERGED_FLAG,
+  OCS_ATTACHED_DEVICES_FLAG,
 } from './features';
-import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager/src/models';
-import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
-import { referenceForModel, referenceFor } from '@console/internal/module/k8s';
-import { PersistentVolumeClaimModel } from '@console/internal/models';
-import { getCephHealthState } from './components/dashboard-page/storage-dashboard/status-card/utils';
-import { isClusterExpandActivity } from './components/dashboard-page/storage-dashboard/activity-card/cluster-expand-activity';
-import { WatchCephResource } from './types';
 
 type ConsumedExtensions =
   | ModelFeatureFlag
+  | HorizontalNavTab
   | ModelDefinition
   | DashboardsTab
   | DashboardsCard
@@ -47,7 +53,8 @@ type ConsumedExtensions =
   | ResourceTabPage
   | ClusterServiceVersionAction
   | KebabActions
-  | DashboardsOverviewResourceActivity;
+  | DashboardsOverviewResourceActivity
+  | StorageClassProvisioner;
 
 const apiObjectRef = referenceForModel(models.OCSServiceModel);
 
@@ -78,18 +85,15 @@ const plugin: Plugin<ConsumedExtensions> = [
     },
   },
   {
-    type: 'Page/Resource/Tab',
+    type: 'FeatureFlag/Custom',
     properties: {
-      href: 'volumesnapshots',
-      model: PersistentVolumeClaimModel,
-      name: 'Volume Snapshots',
-      loader: () =>
-        import('./components/volume-snapshot/volume-snapshot').then(
-          (m) => m.VolumeSnapshotPage,
-        ) /* webpackChunkName: "ceph-storage-volume-snapshot" */,
+      detect: detectRGW,
     },
-    flags: {
-      required: [OCS_SUPPORT_FLAGS.SNAPSHOT, CEPH_FLAG],
+  },
+  {
+    type: 'StorageClass/Provisioner',
+    properties: {
+      getStorageClassProvisioner: StorageClassFormProvisoners,
     },
   },
   {
@@ -114,6 +118,19 @@ const plugin: Plugin<ConsumedExtensions> = [
         ),
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: `/k8s/ns/:ns/${referenceForModel(
+        ClusterServiceVersionModel,
+      )}/:appName/${apiObjectRef}/~new`,
+      loader: () =>
+        import('./components/ocs-install/install-page' /* webpackChunkName: "install-page" */).then(
+          (m) => m.default,
+        ),
+    },
+  },
   // Ceph Storage Dashboard Left cards
   {
     type: 'Dashboards/Card',
@@ -143,6 +160,20 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [CEPH_FLAG],
     },
   },
+  {
+    type: 'Dashboards/Card',
+    properties: {
+      tab: 'persistent-storage',
+      position: GridPosition.LEFT,
+      loader: () =>
+        import(
+          './components/dashboard-page/storage-dashboard/storage-efficiency-card/storage-efficiency-card' /* webpackChunkName: "ceph-storage-efficiency-card" */
+        ).then((m) => m.default),
+    },
+    flags: {
+      required: [CEPH_FLAG],
+    },
+  },
   // Ceph Storage Dashboard Main Cards
   {
     type: 'Dashboards/Card',
@@ -234,6 +265,8 @@ const plugin: Plugin<ConsumedExtensions> = [
             throw e;
           });
       },
+    },
+    flags: {
       disallowed: [OCS_INDEPENDENT_FLAG],
     },
   },
@@ -249,6 +282,8 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/converged-credentials/credentials' /* webpackChunkName: "ceph-storage-export-credentials" */
         ).then((m) => m.default({})),
+    },
+    flags: {
       disallowed: [OCS_INDEPENDENT_FLAG],
     },
   },
@@ -270,7 +305,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       position: GridPosition.LEFT,
       loader: () =>
         import(
-          './components/independent-dashboard-page/details-card/card' /* webpackChunkName: "indepedent-details-card" */
+          './components/independent-dashboard-page/details-card' /* webpackChunkName: "indepedent-details-card" */
         ).then((m) => m.default),
     },
     flags: {
@@ -299,7 +334,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       position: GridPosition.MAIN,
       loader: () =>
         import(
-          './components/independent-dashboard-page/status-card/card' /* webpackChunkName: "indepedent-status-card" */
+          './components/independent-dashboard-page/status-card' /* webpackChunkName: "indepedent-status-card" */
         ).then((m) => m.default),
     },
     flags: {
@@ -313,7 +348,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       position: GridPosition.MAIN,
       loader: () =>
         import(
-          './components/independent-dashboard-page/breakdown-card/card' /* webpackChunkName: "independent-breakdown-card" */
+          './components/independent-dashboard-page/breakdown-card' /* webpackChunkName: "independent-breakdown-card" */
         ).then((m) => m.default),
     },
     flags: {
@@ -327,7 +362,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       position: GridPosition.MAIN,
       loader: () =>
         import(
-          './components/independent-dashboard-page/utilization-card/card' /* webpackChunkName: "utilization-card" */
+          './components/independent-dashboard-page/utilization-card' /* webpackChunkName: "utilization-card" */
         ).then((m) => m.default),
     },
     flags: {
@@ -349,20 +384,6 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [OCS_INDEPENDENT_FLAG],
     },
   },
-  {
-    type: 'Page/Resource/Details',
-    properties: {
-      model: models.VolumeSnapshotModel,
-      loader: async () =>
-        import(
-          './components/volume-snapshot/volume-snapshot' /* webpackChunkName: "ceph-storage-volume-snapshot-details" */
-        ).then((m) => m.VolumeSnapshotDetails),
-      modelParser: referenceFor,
-    },
-    flags: {
-      required: [OCS_SUPPORT_FLAGS.SNAPSHOT, CEPH_FLAG],
-    },
-  },
   {
     type: 'Dashboards/Overview/Activity/Resource',
     properties: {
@@ -382,6 +403,23 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [CEPH_FLAG],
     },
   },
+  {
+    type: 'HorizontalNavTab',
+    properties: {
+      model: NodeModel,
+      page: {
+        href: 'disks',
+        name: 'Disks',
+      },
+      loader: () =>
+        import(
+          './components/attached-devices-mode/lso-disk-inventory/ocs-disks-list' /* webpackChunkName: "ocs-nodes-disks-list" */
+        ).then((m) => m.OCSNodesDiskListPage),
+    },
+    flags: {
+      required: [OCS_ATTACHED_DEVICES_FLAG, LSO_DEVICE_DISCOVERY],
+    },
+  },
 ];
 
 export default plugin;
