@@ -1,4 +1,5 @@
 import * as _ from 'lodash';
+import { isGraph, Node } from '@patternfly/react-topology';
 import {
   K8sKind,
   k8sGet,
@@ -7,11 +8,8 @@ import {
   k8sKill,
   K8sResourceKind,
   modelFor,
-  k8sCreate,
-  LabelSelector,
   referenceFor,
   referenceForModel,
-  apiVersionForModel,
 } from '@console/internal/module/k8s';
 import {
   ImageStreamModel,
@@ -23,16 +21,26 @@ import {
   SecretModel,
   DaemonSetModel,
   StatefulSetModel,
+  JobModel,
+  CronJobModel,
 } from '@console/internal/models';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import { ServiceModel as KnativeServiceModel } from '@console/knative-plugin/src/models';
 import { isDynamicEventResourceKind } from '@console/knative-plugin/src/utils/fetch-dynamic-eventsources-utils';
 import { checkAccess } from '@console/internal/components/utils';
 import { getOperatorBackedServiceKindMap } from '@console/shared';
-import { CREATE_APPLICATION_KEY, UNASSIGNED_KEY } from '../const';
-import { TopologyDataObject, ConnectsToData } from '../components/topology/topology-types';
+import { CREATE_APPLICATION_KEY, UNASSIGNED_KEY, UNASSIGNED_LABEL } from '../const';
+import {
+  TopologyDataObject,
+  ConnectsToData,
+  OdcNodeModel,
+} from '../components/topology/topology-types';
 import { detectGitType } from '../components/import/import-validation-utils';
-import { ServiceBindingModel } from '../models';
+import { createServiceBinding } from '../components/topology/operators/actions/serviceBindings';
+import { TYPE_APPLICATION_GROUP } from '../components/topology/components/const';
+
+export const isWorkloadRegroupable = (node: Node): boolean =>
+  isGraph(node?.getParent()) || node?.getParent().getType() === TYPE_APPLICATION_GROUP;
 
 export const sanitizeApplicationValue = (
   application: string,
@@ -40,6 +48,7 @@ export const sanitizeApplicationValue = (
 ): string => {
   switch (applicationType) {
     case UNASSIGNED_KEY:
+      return UNASSIGNED_LABEL;
     case CREATE_APPLICATION_KEY:
       return '';
     default:
@@ -62,31 +71,6 @@ export const edgesFromAnnotations = (annotations): (string | ConnectsToData)[] =
   return edges;
 };
 
-export const edgesFromServiceBinding = (
-  source: K8sResourceKind,
-  sbrs: K8sResourceKind[],
-): K8sResourceKind[] => {
-  const sourceBindings = [];
-  _.forEach(sbrs, (sbr) => {
-    let edgeExists = false;
-    if (_.get(sbr, 'spec.application.resource') === modelFor(referenceFor(source)).plural) {
-      if (_.get(sbr, 'spec.application.name') === source.metadata.name) {
-        edgeExists = true;
-      } else {
-        const matchLabels = _.has(sbr, 'spec.application.matchLabels');
-        if (matchLabels) {
-          const sbrSelector = new LabelSelector(sbr.spec.application);
-          if (sbrSelector.matches(source)) {
-            edgeExists = true;
-          }
-        }
-      }
-    }
-    edgeExists && sourceBindings.push(sbr);
-  });
-  return sourceBindings;
-};
-
 const listInstanceResources = (
   namespace: string,
   instanceName: string,
@@ -244,58 +228,6 @@ const updateItemAppConnectTo = (
   return k8sPatch(model, item, patch);
 };
 
-export const createServiceBinding = (
-  source: K8sResourceKind,
-  target: K8sResourceKind,
-): Promise<K8sResourceKind> => {
-  if (!source || !target || source === target) {
-    return Promise.reject();
-  }
-
-  const targetName = _.get(target, 'metadata.name');
-  const sourceName = _.get(source, 'metadata.name');
-  const namespace = _.get(source, 'metadata.namespace');
-  const sourceGroup = _.split(_.get(source, 'apiVersion'), '/');
-  const targetResourceGroup = _.split(_.get(target, 'metadata.ownerReferences[0].apiVersion'), '/');
-  const targetResourceKind = _.get(target, 'metadata.ownerReferences[0].kind');
-  const targetResourceRefName = _.get(target, 'metadata.ownerReferences[0].name');
-  const sbrName = `${sourceName}-${modelFor(referenceFor(source)).abbr}-${targetName}-${
-    modelFor(target.kind).abbr
-  }`;
-
-  const serviceBinding = {
-    apiVersion: apiVersionForModel(ServiceBindingModel),
-    kind: ServiceBindingModel.kind,
-    metadata: {
-      name: sbrName,
-      namespace,
-    },
-    spec: {
-      application: {
-        name: sourceName,
-        group: sourceGroup[0],
-        version: sourceGroup[1],
-        resource: modelFor(referenceFor(source)).plural,
-      },
-      services: [
-        {
-          group: targetResourceGroup[0],
-          version: targetResourceGroup[1],
-          kind: targetResourceKind,
-          name: targetResourceRefName,
-        },
-      ],
-      detectBindingResources: true,
-    },
-  };
-
-  return k8sCreate(ServiceBindingModel, serviceBinding);
-};
-
-export const removeServiceBinding = (sbr: K8sResourceKind): Promise<any> => {
-  return k8sKill(ServiceBindingModel, sbr);
-};
-
 // Get the index of the replaced target of the visual connector
 const getReplacedTargetIndex = (
   replacedTarget: K8sResourceKind,
@@ -450,19 +382,27 @@ const deleteWebhooks = (
   }, []);
 };
 
-export const cleanUpWorkload = (
-  resource: K8sResourceKind,
-  workload: TopologyDataObject,
-): Promise<K8sResourceKind[]> => {
+export const cleanUpWorkload = async (workload: OdcNodeModel): Promise<K8sResourceKind[]> => {
+  const { resource } = workload;
   const reqs = [];
-  const isBuildConfigPresent = !_.isEmpty(workload?.resources?.buildConfigs);
-
+  const isBuildConfigPresent = !_.isEmpty(workload.data?.resources?.buildConfigs);
+  const isImageStreamPresent = await k8sGet(
+    ImageStreamModel,
+    resource.metadata.name,
+    resource.metadata.namespace,
+  )
+    .then(() => true)
+    .catch(() => false);
   const deleteModels = [ServiceModel, RouteModel];
-  const knativeDeleteModels = [KnativeServiceModel, ImageStreamModel];
+  const knativeDeleteModels = [KnativeServiceModel];
   if (isBuildConfigPresent) {
     deleteModels.push(BuildConfigModel);
     knativeDeleteModels.push(BuildConfigModel);
   }
+  if (isImageStreamPresent) {
+    deleteModels.push(ImageStreamModel);
+    knativeDeleteModels.push(ImageStreamModel);
+  }
   const resourceData = _.cloneDeep(resource);
   const deleteRequest = (model: K8sKind, resourceObj: K8sResourceKind) => {
     const req = safeKill(model, resourceObj);
@@ -476,13 +416,14 @@ export const cleanUpWorkload = (
   switch (resource.kind) {
     case DaemonSetModel.kind:
     case StatefulSetModel.kind:
+    case JobModel.kind:
+    case CronJobModel.kind:
       deleteRequest(modelFor(resource.kind), resource);
       break;
     case DeploymentModel.kind:
     case DeploymentConfigModel.kind:
       deleteRequest(modelFor(resource.kind), resource);
       batchDeleteRequests(deleteModels, resource);
-      deleteRequest(ImageStreamModel, resource); // delete imageStream
       break;
     case KnativeServiceModel.kind:
       batchDeleteRequests(knativeDeleteModels, resourceData);
@@ -490,7 +431,7 @@ export const cleanUpWorkload = (
     default:
       break;
   }
-  isBuildConfigPresent && reqs.push(...deleteWebhooks(resource, workload));
+  isBuildConfigPresent && reqs.push(...deleteWebhooks(resource, workload.data));
   return Promise.all(reqs);
 };
 
