@@ -1,11 +1,6 @@
 import { apiVersionForModel, K8sResourceCommon } from '@console/internal/module/k8s';
 import { LocalVolumeDiscovery as AutoDetectVolumeModel } from '../../models';
-import {
-  DISCOVERY_CR_NAME,
-  LOCAL_STORAGE_NAMESPACE,
-  HOSTNAME_LABEL_KEY,
-  LABEL_OPERATOR,
-} from '../../constants';
+import { DISCOVERY_CR_NAME, HOSTNAME_LABEL_KEY, LABEL_OPERATOR } from '../../constants';
 import { getNodes, getHostNames } from '../../utils';
 import { HostNamesMap } from './types';
 
@@ -14,17 +9,19 @@ export const getDiscoveryRequestData = ({
   allNodeNamesOnADV,
   showNodesListOnADV,
   hostNamesMapForADV,
+  ns,
 }: {
   nodeNamesForLVS: string[];
   allNodeNamesOnADV: string[];
   showNodesListOnADV: boolean;
   hostNamesMapForADV: HostNamesMap;
+  ns: string;
 }): AutoDetectVolumeKind => {
   const nodes = getNodes(showNodesListOnADV, allNodeNamesOnADV, nodeNamesForLVS);
   return {
     apiVersion: apiVersionForModel(AutoDetectVolumeModel),
     kind: AutoDetectVolumeModel.kind,
-    metadata: { name: DISCOVERY_CR_NAME, namespace: LOCAL_STORAGE_NAMESPACE },
+    metadata: { name: DISCOVERY_CR_NAME, namespace: ns },
     spec: {
       nodeSelector: {
         nodeSelectorTerms: [
